@@ -1,3 +1,5 @@
+"""build/update the fallback 'catch-all' stubfolder"""
+
 import os
 import shutil
 from distutils.dir_util import copy_tree
@@ -13,6 +15,7 @@ RELEASED = "v1_18"
 
 
 def fallback_sources(version: str, fw_version: Optional[str] = None) -> List[Tuple[str, str]]:
+    # sourcery skip: inline-immediately-returned-variable
     """
     list of sources to build/update the fallback 'catch-all' stubfolder
     version : the version to use
@@ -81,7 +84,7 @@ def update_fallback(stubpath: Path, fallback_path: Path, version: str = RELEASED
             except OSError as e:
                 log.warning(e)
     added = 0
-    for (name, source) in fallback_sources(version):
+    for name, source in fallback_sources(version):
         if "." not in name:
             # copy folder
             log.debug(f"add {source} folder")
